==> ejc-jltest-api-3.0.0-20240328.002507-125-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangerbDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细B
 * 
 * @author generator
 * 
 */
public class DangerbDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerbDangerId; // 主表主键ID
    private String dangerbDetailCode; // 隐患编号
    private Long dangerbDetailType; // 类别
    private String dangerbDetailManage; // 管理环节
    private String dangerbDetailContent; // 隐患内容
    private String dangerbSelfExamination; // 自查情况
    private String dangerbDetailResult; // 判定结果
    private String dangerbDetailMemo; // 备注
    

    public Long getDangerbDangerId() {
        return dangerbDangerId;
    }

    public void setDangerbDangerId(Long dangerbDangerId) {
        this.dangerbDangerId = dangerbDangerId;
    }
    public String getDangerbDetailCode() {
        return dangerbDetailCode;
    }

    public void setDangerbDetailCode(String dangerbDetailCode) {
        this.dangerbDetailCode = dangerbDetailCode;
    }
    public Long getDangerbDetailType() {
        return dangerbDetailType;
    }

    public void setDangerbDetailType(Long dangerbDetailType) {
        this.dangerbDetailType = dangerbDetailType;
    }
    public String getDangerbDetailManage() {
        return dangerbDetailManage;
    }

    public void setDangerbDetailManage(String dangerbDetailManage) {
        this.dangerbDetailManage = dangerbDetailManage;
    }
    public String getDangerbDetailContent() {
        return dangerbDetailContent;
    }

    public void setDangerbDetailContent(String dangerbDetailContent) {
        this.dangerbDetailContent = dangerbDetailContent;
    }
    public String getDangerbSelfExamination() {
        return dangerbSelfExamination;
    }

    public void setDangerbSelfExamination(String dangerbSelfExamination) {
        this.dangerbSelfExamination = dangerbSelfExamination;
    }
    public String getDangerbDetailResult() {
        return dangerbDetailResult;
    }

    public void setDangerbDetailResult(String dangerbDetailResult) {
        this.dangerbDetailResult = dangerbDetailResult;
    }
    public String getDangerbDetailMemo() {
        return dangerbDetailMemo;
    }

    public void setDangerbDetailMemo(String dangerbDetailMemo) {
        this.dangerbDetailMemo = dangerbDetailMemo;
    }
    
}

==> ejc-jltest-api-3.0.0-20251024.061248-161-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangerbDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细B
 * 
 * @author generator
 * 
 */
public class DangerbDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerbDangerId; // 主表主键ID
    private String dangerbDetailCode; // 隐患编号
    private Long dangerbDetailType; // 类别
    private String dangerbDetailManage; // 管理环节
    private String dangerbDetailContent; // 隐患内容
    private String dangerbSelfExamination; // 自查情况
    private String dangerbDetailResult; // 判定结果
    private String dangerbDetailMemo; // 备注
    

    public Long getDangerbDangerId() {
        return dangerbDangerId;
    }

    public void setDangerbDangerId(Long dangerbDangerId) {
        this.dangerbDangerId = dangerbDangerId;
    }
    public String getDangerbDetailCode() {
        return dangerbDetailCode;
    }

    public void setDangerbDetailCode(String dangerbDetailCode) {
        this.dangerbDetailCode = dangerbDetailCode;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getDangerbDetailType() {
        return dangerbDetailType;
    }
    @ReferDeserialTransfer
    public void setDangerbDetailType(Long dangerbDetailType) {
        this.dangerbDetailType = dangerbDetailType;
    }
    public String getDangerbDetailManage() {
        return dangerbDetailManage;
    }

    public void setDangerbDetailManage(String dangerbDetailManage) {
        this.dangerbDetailManage = dangerbDetailManage;
    }
    public String getDangerbDetailContent() {
        return dangerbDetailContent;
    }

    public void setDangerbDetailContent(String dangerbDetailContent) {
        this.dangerbDetailContent = dangerbDetailContent;
    }
    public String getDangerbSelfExamination() {
        return dangerbSelfExamination;
    }

    public void setDangerbSelfExamination(String dangerbSelfExamination) {
        this.dangerbSelfExamination = dangerbSelfExamination;
    }
    public String getDangerbDetailResult() {
        return dangerbDetailResult;
    }

    public void setDangerbDetailResult(String dangerbDetailResult) {
        this.dangerbDetailResult = dangerbDetailResult;
    }
    public String getDangerbDetailMemo() {
        return dangerbDetailMemo;
    }

    public void setDangerbDetailMemo(String dangerbDetailMemo) {
        this.dangerbDetailMemo = dangerbDetailMemo;
    }
    
}
